"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const convert_1 = __importDefault(require("./convert"));
const parser_1 = __importDefault(require("./utils/parser"));
class Cashify {
    /**
    * @constructor
    * @param {Object} [options] Conversion options.
    */
    constructor(options) {
        this.options = options;
    }
    /**
    * Function, which converts currencies based on provided rates.
    *
    * @param {number | string} amount - Amount of money you want to convert.
    * @param {Object} [options] - Conversion options.
    * @return {number} Conversion result.
    *
    * @example
    * const rates = {
    * 	GBP: 0.92,
    * 	EUR: 1.00,
    * 	USD: 1.12
    * };
    *
    * const cashify = new Cashify({base: 'EUR', rates});
    *
    * cashify.convert(10, {from: 'EUR', to: 'GBP'}); //=> 9.2
    */
    convert(amount, options) {
        // If provided `amount` is a string, use parsing
        if (typeof amount === 'string') {
            const data = parser_1.default(amount);
            return convert_1.default(data.amount, { ...this.options, from: data.from, to: data.to, ...options });
        }
        return convert_1.default(amount, { ...this.options, ...options });
    }
}
exports.default = Cashify;
